==> jc-1.4.0.tar.gz: ppg/atoms/GrammarPart.c <==
// public abstract class ppg.atoms.GrammarPart

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class ad102a5c5cfc3a0e ppg_atoms_GrammarPart
// @dep_class 904d423ee80cc75f ppg_parse_Unparse

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header ppg_atoms_GrammarPart
// @dep_header ppg_parse_Unparse

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "ppg/atoms/GrammarPart.h"
#include "ppg/parse/Unparse.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_ppg_atoms_GrammarPart$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_ppg_atoms_GrammarPart$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_ppg_atoms_GrammarPart$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_ppg_atoms_GrammarPart$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_ppg_atoms_GrammarPart$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_ppg_atoms_GrammarPart$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_ppg_atoms_GrammarPart$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(ppg_atoms_GrammarPart, _init$52f4ad9f2989aeee);

void
_jc_ppg_atoms_GrammarPart$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_ppg_atoms_GrammarPart$object *this)
{
	struct _jc_ppg_atoms_GrammarPart$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(5);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public abstract java.lang.Object clone()
//

static const unsigned char _jc_ppg_atoms_GrammarPart$param_ptypes$clone$b75f2713d6705f70[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_ppg_atoms_GrammarPart$method_info$clone$b75f2713d6705f70 = {
	.name=			"clone",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_ppg_atoms_GrammarPart$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_ppg_atoms_GrammarPart$param_ptypes$clone$b75f2713d6705f70,
	.signature_hash=	_JC_JLONG(0xb75f2713d6705f70),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_ppg_atoms_GrammarPart$method$clone$b75f2713d6705f70,
	.vtable_index=		_JC_OFFSETOF(struct _jc_ppg_atoms_GrammarPart$vtable, ppg_atoms_GrammarPart.clone$b75f2713d6705f70) / sizeof(void *),
	.num_parameters=	0,
};

_jc_java_lang_Object$object *
_jc_ppg_atoms_GrammarPart$method$clone$b75f2713d6705f70(_jc_env *const env, _jc_ppg_atoms_GrammarPart$object *this)
{
	_JC_ABSTRACT_METHOD(env, &_jc_ppg_atoms_GrammarPart$method_info$clone$b75f2713d6705f70);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_ppg_atoms_GrammarPart$methods[] = {
	&_jc_ppg_atoms_GrammarPart$method_info$_init$52f4ad9f2989aeee,
	&_jc_ppg_atoms_GrammarPart$method_info$clone$b75f2713d6705f70
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_ppg_atoms_GrammarPart$interfaces[] = {
	&_jc_ppg_parse_Unparse$type
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_ppg_atoms_GrammarPart$instanceof_hash_bucket_14[] = {
	&_jc_ppg_atoms_GrammarPart$type,
	_JC_NULL
};
static _jc_type *const _jc_ppg_atoms_GrammarPart$instanceof_hash_bucket_95[] = {
	&_jc_ppg_parse_Unparse$type,
	_JC_NULL
};
static _jc_type *const _jc_ppg_atoms_GrammarPart$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_ppg_atoms_GrammarPart$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[14]=	_jc_ppg_atoms_GrammarPart$instanceof_hash_bucket_14,
	[95]=	_jc_ppg_atoms_GrammarPart$instanceof_hash_bucket_95,
	[113]=	_jc_ppg_atoms_GrammarPart$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_ppg_atoms_GrammarPart$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "ppg/parse/Unparse",	_JC_JLONG(0x904d423ee80cc75f) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_ppg_atoms_GrammarPart$vtype _jc_ppg_atoms_GrammarPart$type = {
    .type= {
	.name=			"ppg/atoms/GrammarPart",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_ppg_atoms_GrammarPart$interfaces) / sizeof(*_jc_ppg_atoms_GrammarPart$interfaces),
	.interfaces=		_jc_ppg_atoms_GrammarPart$interfaces,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xad102a5c5cfc3a0e),
		.source_file=		"GrammarPart.java",
		.instance_size=		sizeof(_jc_ppg_atoms_GrammarPart$refs) + sizeof(_jc_ppg_atoms_GrammarPart$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_ppg_atoms_GrammarPart$methods) / sizeof(*_jc_ppg_atoms_GrammarPart$methods),
		.methods=		_jc_ppg_atoms_GrammarPart$methods,
		.instanceof_hash_table=	_jc_ppg_atoms_GrammarPart$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_ppg_atoms_GrammarPart$class_depends) / sizeof(*_jc_ppg_atoms_GrammarPart$class_depends),
		.class_depends=		_jc_ppg_atoms_GrammarPart$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=			// overridden
		&_jc_ppg_atoms_GrammarPart$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.ppg_atoms_GrammarPart= {
	    .clone$b75f2713d6705f70=
		&_jc_ppg_atoms_GrammarPart$method$clone$b75f2713d6705f70,
	},
    }
};

==> jc-1.4.5.tar.gz: ppg/atoms/GrammarPart.c <==
// public abstract class ppg.atoms.GrammarPart

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class ad102a5c5cfc3a0e ppg_atoms_GrammarPart
// @dep_class 904d423ee80cc75f ppg_parse_Unparse

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header ppg_atoms_GrammarPart
// @dep_header ppg_parse_Unparse

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "ppg/atoms/GrammarPart.h"
#include "ppg/parse/Unparse.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_ppg_atoms_GrammarPart$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_ppg_atoms_GrammarPart$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_ppg_atoms_GrammarPart$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_ppg_atoms_GrammarPart$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_ppg_atoms_GrammarPart$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_ppg_atoms_GrammarPart$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_ppg_atoms_GrammarPart$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(ppg_atoms_GrammarPart, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_ppg_atoms_GrammarPart$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_ppg_atoms_GrammarPart$object *this)
{
	struct _jc_ppg_atoms_GrammarPart$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(5);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public abstract java.lang.Object clone()
//

static const unsigned char _jc_ppg_atoms_GrammarPart$param_ptypes$clone$b75f2713d6705f70[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_ppg_atoms_GrammarPart$method_info$clone$b75f2713d6705f70 = {
	.name=			"clone",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_ppg_atoms_GrammarPart$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_ppg_atoms_GrammarPart$param_ptypes$clone$b75f2713d6705f70,
	.signature_hash=	_JC_JLONG(0xb75f2713d6705f70),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_ppg_atoms_GrammarPart$method$clone$b75f2713d6705f70,
	.vtable_index=		_JC_OFFSETOF(struct _jc_ppg_atoms_GrammarPart$vtable, ppg_atoms_GrammarPart.clone$b75f2713d6705f70) / sizeof(void *),
	.num_parameters=	0,
};

_jc_java_lang_Object$object * _JC_JCNI_ATTR
_jc_ppg_atoms_GrammarPart$method$clone$b75f2713d6705f70(_jc_env *const env, _jc_ppg_atoms_GrammarPart$object *this)
{
	_JC_ABSTRACT_METHOD(env, &_jc_ppg_atoms_GrammarPart$method_info$clone$b75f2713d6705f70);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_ppg_atoms_GrammarPart$methods[] = {
	&_jc_ppg_atoms_GrammarPart$method_info$_init$52f4ad9f2989aeee,
	&_jc_ppg_atoms_GrammarPart$method_info$clone$b75f2713d6705f70
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_ppg_atoms_GrammarPart$interfaces[] = {
	&_jc_ppg_parse_Unparse$type
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_ppg_atoms_GrammarPart$instanceof_hash_bucket_14[] = {
	&_jc_ppg_atoms_GrammarPart$type,
	_JC_NULL
};
static _jc_type *const _jc_ppg_atoms_GrammarPart$instanceof_hash_bucket_95[] = {
	&_jc_ppg_parse_Unparse$type,
	_JC_NULL
};
static _jc_type *const _jc_ppg_atoms_GrammarPart$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_ppg_atoms_GrammarPart$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[14]=	_jc_ppg_atoms_GrammarPart$instanceof_hash_bucket_14,
	[95]=	_jc_ppg_atoms_GrammarPart$instanceof_hash_bucket_95,
	[101]=	_jc_ppg_atoms_GrammarPart$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_ppg_atoms_GrammarPart$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "ppg/parse/Unparse",	_JC_JLONG(0x904d423ee80cc75f) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_ppg_atoms_GrammarPart$vtype _jc_ppg_atoms_GrammarPart$type = {
    .type= {
	.name=			"ppg/atoms/GrammarPart",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_ppg_atoms_GrammarPart$interfaces) / sizeof(*_jc_ppg_atoms_GrammarPart$interfaces),
	.interfaces=		_jc_ppg_atoms_GrammarPart$interfaces,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xad102a5c5cfc3a0e),
		.source_file=		"GrammarPart.java",
		.instance_size=		sizeof(_jc_ppg_atoms_GrammarPart$refs) + sizeof(_jc_ppg_atoms_GrammarPart$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_ppg_atoms_GrammarPart$methods) / sizeof(*_jc_ppg_atoms_GrammarPart$methods),
		.methods=		_jc_ppg_atoms_GrammarPart$methods,
		.instanceof_hash_table=	_jc_ppg_atoms_GrammarPart$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_ppg_atoms_GrammarPart$class_depends) / sizeof(*_jc_ppg_atoms_GrammarPart$class_depends),
		.class_depends=		_jc_ppg_atoms_GrammarPart$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=			// overridden
		&_jc_ppg_atoms_GrammarPart$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.ppg_atoms_GrammarPart= {
	    .clone$b75f2713d6705f70=
		&_jc_ppg_atoms_GrammarPart$method$clone$b75f2713d6705f70,
	},
    }
};
